#!/bin/sh
#************global value start***
CURRENT_USER=`echo $USER`
CHECK_ITEM_FUNCTION=""
MATCHED_ZIP_PKG_NAME=""
PKG_CERT_FLAG=1
VMWARE_V_VERSION=""
LOG_FILE="/scratch/log/esxupdate.log"
INSTALL_LOCK_FILE="/var/lock/nxup_upgrade"
INSTALL_SCRIPT_DIR=`pwd`
BACKUP_PKG_DIR=/etc/UltraPath/package 
GLOBAL_CMD_ECHO=""

BATCH_CHECK_ITEM="
c010001 checkUserRootAuthority
c010002 checkOSVersionCompatibility
c010003 checkRemainingSpace
c010004 checkExistInstallRunning
c010005 checkExistInstalledVib
c010006 checkExistClaimRule
c010007 checkPackageIntegrity
c110001 checkAfterInstallProcess
c110002 checkPackageInstalled
c110003 checkSoftwareVersion
c110004 checkLogFileSizeAdvise"

#***********common function********
#将错误日志写到日志文件
writeErrorLog()
{
    local date=`date '+%Y-%m-%d %H:%M:%S'`
    echo "[$date][ULTRAPATH][${CURRENT_USER}][ERROR][$2] $1" >> "${LOG_FILE}"
}

#info级别日志写到文件
writeInfoLog()
{
    local date=`date '+%Y-%m-%d %H:%M:%S'`
    echo "[$date][ULTRAPATH][${CURRENT_USER}][INFO][$2] $1" >> "${LOG_FILE}"
}

#删除备份文件，终端打印日志并异常退出
exitWithPrintErrorLog()
{
    echo -e "$1"
    writeErrorLog "$1" "$2"
    exit 1
}

exitWithPrintInfoLog()
{
    echo -e "$1"
    writeInfoLog "$1" "$2"
    exit 0
}

#**********init global value function*******
initCurrentDirectory()
{
    local path_check1=`echo $(dirname $0)|grep '^[.]'|wc -l`
    local path_check2=`echo $(dirname $0)|grep '^[/]'|wc -l`
    if [ ${path_check1} -ne 0 ]; then
        INSTALL_SCRIPT_DIR=${INSTALL_SCRIPT_DIR}/$(dirname $0)
    elif [ ${path_check2} -ne 0 ]; then
        INSTALL_SCRIPT_DIR=$(dirname $0)
    else
        local path_check3=`echo ${0}|grep "/"|wc -l`
        if [ ${path_check3} -ne 0 ]; then
            INSTALL_SCRIPT_DIR=${INSTALL_SCRIPT_DIR}/$(dirname $0)
        else
            INSTALL_SCRIPT_DIR=${INSTALL_SCRIPT_DIR}
        fi
    fi
}

executeCmdAndGetEcho()
{
    GLOBAL_CMD_ECHO=`$1`
    local ret=$? 
    echo "#$1"
    echo "${GLOBAL_CMD_ECHO}"
    if [ ${ret} -ne 0 ] 
    then
        exitWithPrintErrorLog "Check result: The \"$1\" command fails to be executed. Contact Huawei technical support." "$2"
    fi
}

getMatchedZipPackageByOSVersion()
{
    local os_version=$1
    local pkg_esxi_version=""
    if [ "${os_version}" == "5.0.0" ] || [ "${os_version}" == "5.1.0" ]; then
        pkg_esxi_version=ESXi5.0
    elif [ "${os_version}" == "5.5.0" ]; then
        pkg_esxi_version=ESXi5.5
    elif [ "${os_version}" == "6.0.0" ] || [ "${os_version}" == "6.5.0" ] || [ "${os_version}" == "6.7.0" ]; then
        pkg_esxi_version=ESXi6.x
    fi

    executeCmdAndGetEcho "ls ${INSTALL_SCRIPT_DIR}" "getMatchedZipPackageByOSVersion"
    local file_list=${GLOBAL_CMD_ECHO}
    local pkg_file_count=`echo "${file_list}" | grep -c "^UltraPath-21.0[0-9].[0-9][0-9][0-9]-${pkg_esxi_version}-offline-bundle.zip$"`  
    if [ ${pkg_file_count} -eq 0 ]
    then
        return 1
    elif [ ${pkg_file_count} -gt 1 ]
    then
        return 2
    fi
    
    MATCHED_ZIP_PKG_NAME=`echo "${file_list}" | grep "^UltraPath-21.0[0-9].[0-9][0-9][0-9]-${pkg_esxi_version}-offline-bundle.zip$"`
    return 0
}

checkClaimruleVendor()
{
    local vendor_name=$1
    local product_name=$2
    local claim_rule=$3

    local vendor_count=`echo "${claim_rule}" | grep -E "\<vendor=${vendor_name}\>" | grep -c -E "model=\*"`
    if [ ${vendor_count} -ne 0 ]
    then
        local vendor_rule_no=`echo "${claim_rule}" | grep -E "\<vendor=$vendor_name\>" | grep "model=\*" |grep file |awk '{print $2}'`
        if [ ${vendor_rule_no} -lt 400 ]
        then
            exitWithPrintErrorLog "Check result: A takeover rule conflicts with UltraPath." "checkExistClaimRule"
        fi
    fi

    local vendor_product_count=`echo "${claim_rule}" | grep -E "\<vendor=$vendor_name\>" | grep -c -E "\<model=$product_name\>"`
    if [ ${vendor_product_count} -ne 0 ]
    then
        exitWithPrintErrorLog "Check result: A takeover rule conflicts with UltraPath." "checkExistClaimRule"
    fi
}

#**********check function*********
#检查是否是root c010001
checkUserRootAuthority()
{
    local cmd_ret=`echo $USER`
    echo "#echo \$USER"
    echo "${cmd_ret}"
    if [ "${cmd_ret}" != "root" ]
    then
        exitWithPrintErrorLog "Check result: The current user is not user \"root\"." "checkUserRootAuthority"
    else
        exitWithPrintInfoLog "Check result: Pass" "checkUserRootAuthority"
    fi
}

#检查操作系统版本是否支持 c000007
checkOSVersionCompatibility()
{
    executeCmdAndGetEcho "vmware -v" "checkOSVersionCompatibility"
    VMWARE_V_VERSION="${GLOBAL_CMD_ECHO}"
    local os_version=`echo "${VMWARE_V_VERSION}" | awk '{print $3}'`
    if [ "$os_version" != "5.0.0" ] && [ "$os_version" != "5.1.0" ] && [ "$os_version" != "5.5.0" ] && [ "$os_version" != "6.0.0" ] && [ "$os_version" != "6.5.0" ] && [ "$os_version" != "6.7.0" ]
    then
        exitWithPrintErrorLog "Check result: UltraPath does not support ESXi of this version." "checkOSVersionCompatibility"
    fi
    
    #处理6.7.0不支持21.1.0版本UltraPath的问题
    getMatchedZipPackageByOSVersion ${os_version}
    if [ $? -ne 0 ] 
    then 
        exitWithPrintInfoLog "Check result: Pass" "checkOSVersionCompatibility"
    fi
    
    local pkg_name_tmp1=${MATCHED_ZIP_PKG_NAME#*-}
    local pkg_name_tmp2=${pkg_name_tmp1%%-*}
    local pkg_version=${pkg_name_tmp2%.*}
    if [ "${os_version}" == "6.7.0" ] && [ "${pkg_version}" == "21.02" ]
    then
        exitWithPrintErrorLog "Check result: UltraPath does not support ESXi of this version." "checkOSVersionCompatibility"
    fi

    exitWithPrintInfoLog "Check result: Pass" "checkOSVersionCompatibility"
}

#检查系统的剩余空间c00005
checkRemainingSpace()
{
    executeCmdAndGetEcho "vdf" "checkRemainingSpace"
    local vdf_cmd_echo="${GLOBAL_CMD_ECHO}"
    local etc_remaining_space=`echo "${vdf_cmd_echo}" |grep % |grep etc | awk '{print $4}'`
    local root_remaining_space=`echo "${vdf_cmd_echo}" |grep % |grep root | awk '{print $4}'`
    local tmp_remaining_space=`echo "${vdf_cmd_echo}" |grep % |grep tmp | awk '{print $4}'`
    
    if [ ${etc_remaining_space} -ge 10240 ] && [ ${root_remaining_space} -ge 10240 ] && [ ${tmp_remaining_space} -ge 51200 ]
    then
        exitWithPrintInfoLog "Check result: Pass" "checkRemainingSpace"
    fi
    
    if [ ${etc_remaining_space} -lt 10240 ] && [ ${root_remaining_space} -lt 10240 ] && [ ${tmp_remaining_space} -lt 51200 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /etc is insufficient;\nThe free space of /root is insufficient;\nThe free space of /tmp is insufficient." "checkRemainingSpace"
    elif [ ${etc_remaining_space} -lt 10240 ] && [ ${root_remaining_space} -lt 10240 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /etc is insufficient;\nThe free space of /root is insufficient." "checkRemainingSpace"
    elif [ ${etc_remaining_space} -lt 10240 ] && [ ${tmp_remaining_space} -lt 51200 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /etc is insufficient;\nThe free space of /tmp is insufficient." "checkRemainingSpace"
    elif [ ${root_remaining_space} -lt 10240 ] && [ ${tmp_remaining_space} -lt 51200 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /root is insufficient;\nThe free space of /tmp is insufficient." "checkRemainingSpace"
    elif [ ${etc_remaining_space} -lt 10240 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /etc is insufficient." "checkRemainingSpace"
    elif [ ${root_remaining_space} -lt 10240 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /root is insufficient." "checkRemainingSpace"
    elif [ ${tmp_remaining_space} -lt 51200 ]
    then
        exitWithPrintErrorLog "Check result: The free space of /tmp is insufficient." "checkRemainingSpace"
    fi
}

#检查是否有别的安装脚本在运行
checkExistInstallRunning()
{
    if [ ! -f ${INSTALL_LOCK_FILE} ]
    then
        if [ "$1" == "install" ]
        then
            echo $$ > $INSTALL_LOCK_FILE
            return
        else
            exitWithPrintInfoLog "Check result: Pass." "checkExistInstallRunning"
        fi
    fi
    
    executeCmdAndGetEcho "cat ${INSTALL_LOCK_FILE}" "checkExistInstallRunning"
    local install_pid="${GLOBAL_CMD_ECHO}"
    if [ "${install_pid}" != "" ]
    then
        executeCmdAndGetEcho "ps -c" "checkExistInstallRunning"
        local ps_echo="${GLOBAL_CMD_ECHO}"
        local install_process_count=`echo "${ps_echo}" | awk '{print $1}' | grep -c "^[[:blank:]]*${install_pid}[[:blank:]]*$"`
        if [ ${install_process_count} -gt 0 ]; then
            exitWithPrintErrorLog "Check result: Other UltraPath installation processes are running." "checkExistInstallRunning"
        fi
    fi
    [[ -f ${INSTALL_LOCK_FILE} ]] && rm -rf ${INSTALL_LOCK_FILE}
    if [ "$1" == "install" ]
    then
        echo $$ > $INSTALL_LOCK_FILE
    else
        exitWithPrintInfoLog "Check result: Pass." "checkExistInstallRunning"
    fi
    
}

#检查多路径是否已经安装 c000003
checkExistInstalledVib()
{
    executeCmdAndGetEcho "esxcli software vib list" "checkExistInstalledVib"
    local vib_list="${GLOBAL_CMD_ECHO}"
    local ultrapath_vib_count=`echo "${vib_list}" | grep -c -E "ultrapath.cim|ultrapath.cli|ultrapath.mpp"`
    if [ ${ultrapath_vib_count} -gt 0 ]
    then
        exitWithPrintErrorLog "Check result: UltraPath has been installed in the current environment." "checkExistInstalledVib"
    else
		exitWithPrintInfoLog "Check result: Pass" "checkExistInstalledVib"
    fi
}

#检查冲突的规则
checkExistClaimRule()
{
    executeCmdAndGetEcho "esxcli storage core claimrule list" "checkExistClaimRule"
    local claim_rule_ret="${GLOBAL_CMD_ECHO}"
    local claim_rule_ids=`echo "${claim_rule_ret}" | grep -c -E "\<4[0-6][0-9]\>|\<47[0-7]\>"`
    if [ ${claim_rule_ids} -ne 0 ]
    then 
        exitWithPrintErrorLog "Check result: A takeover rule conflicts with UltraPath." "checkExistClaimRule"
    fi

    local claim_rule_vendor=`echo "${claim_rule_ret}" | grep -c -E "\<HUAWEI\>|\<HUASY\>|\<HS\>"`
    if [ ${claim_rule_vendor} -ne 0 ]
    then 
        exitWithPrintErrorLog "Check result: A takeover rule conflicts with UltraPath." "checkExistClaimRule"
    fi

    checkClaimruleVendor Marstor XSG1 "${claim_rule_ret}"
    checkClaimruleVendor UDsafe XSG1 "${claim_rule_ret}"
    checkClaimruleVendor SanM XSG1 "${claim_rule_ret}"
    checkClaimruleVendor AnyStor XSG1 "${claim_rule_ret}"
    checkClaimruleVendor SUGON XSG1 "${claim_rule_ret}"
    checkClaimruleVendor NETPOSA XSG1 "${claim_rule_ret}"

    exitWithPrintInfoLog "Check result: Pass" "checkExistClaimRule"
}

#检查安装包的完整性 c000006
checkPackageIntegrity()
{
    local install_flag=$1
    executeCmdAndGetEcho "vmware -v" "checkPackageIntegrity"
    VMWARE_V_VERSION="${GLOBAL_CMD_ECHO}"
    local os_version=`echo "${VMWARE_V_VERSION}" | awk '{print $3}'`

    getMatchedZipPackageByOSVersion ${os_version}
    local zipname_ret=$?
    if [ $zipname_ret -eq 1 ] 
    then
        exitWithPrintErrorLog "Check result: The UltraPath software package file is incomplete." "checkPackageIntegrity"
    elif [ $zipname_ret -eq 2 ]
    then
        exitWithPrintErrorLog "Check result: The UltraPath software package file is redundancy." "checkPackageIntegrity"
    fi

	executeCmdAndGetEcho "unzip -l ${INSTALL_SCRIPT_DIR}/${MATCHED_ZIP_PKG_NAME} -x src/" "checkPackageIntegrity"
    local file_list="${GLOBAL_CMD_ECHO}"
	
    local vib20_count_cli=`echo "${file_list}" | grep -c "vib20/ultrapath.cli"`
	local vib20_count_cim=`echo "${file_list}" | grep -c "vib20/ultrapath.cim"`
	local vib20_count_mpp=`echo "${file_list}" | grep -c "vib20/ultrapath.mpp"`
	if [ $vib20_count_cli -eq 1 ] && [ $vib20_count_cim -eq 1 ] && [ $vib20_count_mpp -eq 1 ]
    then
        PKG_CERT_FLAG=0
	else
        VIBCOUNT=`echo "${file_list}" | grep HUAWEI_bootbank_ultrapath | grep -v "vib20"|wc -l`
        if [ $VIBCOUNT -ne 0 ]
        then
            PKG_CERT_FLAG=1
        fi
    fi
    
    local vib_count=`echo "${file_list}" | grep -c -E "HUAWEI_bootbank_ultrapath.cim|HUAWEI_bootbank_ultrapath.cli|HUAWEI_bootbank_ultrapath.mpp"`
    if [ ${vib_count} -lt 3 ]
    then
        exitWithPrintErrorLog "Check result: The UltraPath software package file is incomplete." "checkPackageIntegrity"
    elif [ ${vib_count} -gt 3 ]
    then       
        exitWithPrintErrorLog "Check result: The UltraPath software package file is redundancy." "checkPackageIntegrity"
    fi
    
    local file_count=`echo "${file_list}" | grep -c -E "cfg_upgrade|user_cfg.xml|ouc"`
    if [ ${file_count} -lt 3 ]
    then     
        exitWithPrintErrorLog "Check result: The UltraPath software package file is incomplete." "checkPackageIntegrity"
    elif [ ${file_count} -gt 3 ]
    then      
        exitWithPrintErrorLog "Check result: The UltraPath software package file is redundancy." "checkPackageIntegrity"
    fi
    
    local src_count=`echo "${file_list}" | grep -c -E "src/"`
    if [ ${src_count} -ne 6 ]
    then       
        exitWithPrintErrorLog "Check result: The UltraPath software package file is incomplete." "checkPackageIntegrity"
    fi
    
    if [ "${install_flag}" == "" ] 
    then
        exitWithPrintInfoLog "Check result: Pass" "checkPackageIntegrity"
    fi
}

#安装后处理
checkAfterInstallProcess()
{
    local thisVendor=""
    local thisModel=""
    executeCmdAndGetEcho "esxcli storage core claimrule list" "checkAfterInstallProcess"
    local claimRule_str="${GLOBAL_CMD_ECHO}"
    executeCmdAndGetEcho "esxcli storage core device list" "checkAfterInstallProcess"
    local device_list="${GLOBAL_CMD_ECHO}"
    local diskSet=`echo "${GLOBAL_CMD_ECHO}" |grep -E "^naa"`
    
    for i in $diskSet;do
        executeCmdAndGetEcho "esxcli storage core device list -d $i" "checkAfterInstallProcess"
        if [ `echo "${GLOBAL_CMD_ECHO}" |grep -E -c "\<Multipath Plugin: MP_PLUGIN_ULTRAPATH\>"` -eq 0 ]
        then
            thisVendor=`echo "${GLOBAL_CMD_ECHO}" |grep "Vendor" |awk -F ":" '{print $2}' |sed 's/^[ \t]*//g' | sed 's/[ \t]*$//g'`
            thisModel=`echo "${GLOBAL_CMD_ECHO}" |grep "Model" |awk -F ":" '{print $2}' |sed 's/^[ \t]*//g' | sed 's/[ \t]*$//g'`
            if [ `echo "${claimRule_str}" | grep "runtime"| grep -E "\<MP_PLUGIN_ULTRAPATH\>" | grep -E -c "\<vendor=${thisVendor}[, ]*model=${thisModel}\>"` -gt 0 ]
            then
                exitWithPrintErrorLog "Check result: The host must be restarted to enable UltraPath to take effect." "checkAfterInstallProcess" 
            fi
        fi
    done
    
    local upadm_unavailable=0
    GLOBAL_CMD_ECHO=`esxcli upadm`
    local ret=$?
    echo "#esxcli upadm"
    echo "${GLOBAL_CMD_ECHO}"
    if [ ${ret} -ne 0 ] 
    then 
        upadm_unavailable=1
    fi
    
    executeCmdAndGetEcho "vmware -v" "checkAfterInstallProcess"
    VMWARE_V_VERSION="${GLOBAL_CMD_ECHO}"
    local esxi5_5=`echo "${VMWARE_V_VERSION}" |grep -c "5.5.0"`
    local sub_version1=${VMWARE_V_VERSION#*-}
    local sub_version=${sub_version1%%" "*}
    
    if [ ${upadm_unavailable} -eq 1 ] && [ ${esxi5_5} -eq 1 ] && [ ${sub_version} -lt 1474528 ]
    then
        exitWithPrintErrorLog "Check result: The host must be restarted to enable UltraPath to take effect." "checkAfterInstallProcess"
    fi
    
    local watchdog_status=""
    
    watchdog_status=`/etc/init.d/sfcbd-watchdog status`
    ret=$?
    echo "#/etc/init.d/sfcbd-watchdog status"
    echo "${watchdog_status}"   
    if [ ${ret} -ne 0 ] && [ ${ret} -ne 3 ]
    then
        exitWithPrintErrorLog "Check result: The \"/etc/init.d/sfcbd-watchdog status\" command fails to be executed. Contact Huawei technical support." "checkAfterInstallProcess"
    fi
    local watchdog_notruning=`echo "${watchdog_status}" | grep -c not`
    
    if [ ${upadm_unavailable} -eq 1 ] && [ ${watchdog_notruning} -eq 1 ]
    then
        exitWithPrintErrorLog "Check result: Run the \"/etc/init.d/sfcbd-watchdog start\" command to start the watchdog service so that UltraPath can take effect;\nRun the \"/etc/init.d/hostd restart\" command to restart the hostd service so that UltraPath can take effect." "checkAfterInstallProcess"
    elif [ ${upadm_unavailable} -eq 1 ]
    then
        exitWithPrintErrorLog "Check result: Run the \"/etc/init.d/hostd restart\" command to restart the hostd service so that UltraPath can take effect." "checkAfterInstallProcess"
    elif [ ${watchdog_notruning} -eq 1 ]
    then
        exitWithPrintErrorLog "Check result: Run the \"/etc/init.d/sfcbd-watchdog start\" command to start the watchdog service so that UltraPath can take effect." "checkAfterInstallProcess"
    fi
    
    exitWithPrintInfoLog "Check result: Pass" "checkAfterInstallProcess"
}

#检查是否安装成功
checkPackageInstalled()
{
    executeCmdAndGetEcho "esxcli software vib list" "checkPackageInstalled"
    local vib_list="${GLOBAL_CMD_ECHO}"
    local ultrapath_vib_count=`echo "${vib_list}" | grep -c -E "ultrapath.cim|ultrapath.cli|ultrapath.mpp"`
    if [ ${ultrapath_vib_count} -ne 3 ]
    then
        exitWithPrintErrorLog "Check result: UltraPath fails to be installed. Contact Huawei technical support for troubleshooting." "checkExistInstalledVib"
    else
        exitWithPrintInfoLog "Check result: Pass" "checkPackageInstalled"
    fi
}

#检查UltraPath版本号是否匹配
checkSoftwareVersion()
{
    executeCmdAndGetEcho "esxcli upadm show version" "checkSoftwareVersion"
    local up_version="${GLOBAL_CMD_ECHO}"
    local version=`echo "${up_version}" |grep "Software Version"`
    local software_version=${version##* }
    version=`echo "${up_version}" |grep "Driver   Version"`
    local driver_version=${version##* }
    
    executeCmdAndGetEcho "vmware -v" "checkSoftwareVersion"
    VMWARE_V_VERSION="${GLOBAL_CMD_ECHO}"
    local os_version=`echo "${VMWARE_V_VERSION}" | awk '{print $3}'`
    getMatchedZipPackageByOSVersion ${os_version}
    local zipname_ret=$?
    if [ $zipname_ret -eq 1 ] 
    then 
        exitWithPrintErrorLog "Check result: The UltraPath software package file is incomplete." "checkSoftwareVersion"
    elif [ $zipname_ret -eq 2 ]
    then
        exitWithPrintErrorLog "Check result: The UltraPath software package file is redundancy." "checkSoftwareVersion"
    fi
    
    local pkg_name_tmp=${MATCHED_ZIP_PKG_NAME#*-}
    local pkg_version=${pkg_name_tmp%%-*}
    if [ "${software_version}" != "$pkg_version" ] || [ "${driver_version}" != "$pkg_version" ]
    then
        exitWithPrintErrorLog "Check result: The UltraPath version does not match. Contact Huawei technical support for troubleshooting." "checkSoftwareVersion"
    else
        exitWithPrintInfoLog "Check result: Pass" "checkSoftwareVersion"
    fi
}

#检查日志文件的大小
checkLogFileSizeAdvise()
{
    executeCmdAndGetEcho "esxcli system syslog config logger list" "checkLogFileSizeAdvise"
    local syslog_config="${GLOBAL_CMD_ECHO}"
    local syslog=`echo "${syslog_config}" |grep -C 2 'syslog.log'|grep "Rotation Size"`
    local vmkernel=`echo "${syslog_config}" |grep -C 2 'vmkernel.log'|grep "Rotation Size"`
    local syslog_size=${syslog#*:}
    local vmkernel_size=${vmkernel##*:}

    if [ ${syslog_size} -lt 30720 ] && [ ${vmkernel_size} -lt 30720 ]
    then
        exitWithPrintErrorLog "Check result: The thresholds for dumping syslog.log and vmkernel.log are set to a value less than 30 MB." "checkLogFileSizeAdvise"
    elif [ ${syslog_size} -lt 30720 ]
    then
        exitWithPrintErrorLog "Check result: The threshold for dumping syslog.log is set to a value less than 30 MB." "checkLogFileSizeAdvise"
    elif [ ${vmkernel_size} -lt 30720 ]
    then
        exitWithPrintErrorLog "Check result: The threshold for dumping vmkernel.log is set to a value less than 30 MB." "checkLogFileSizeAdvise"
    fi
    
    exitWithPrintInfoLog "Check result: Pass" "checkLogFileSizeAdvise"
}

getCheckItemFunctionByKey()
{
    local val
    local find=0

    CHECK_ITEM_FUNCTION=""
    if [ $# -gt 2 ] || [ $# -eq 1 ]
    then
         exitWithPrintErrorLog "Check result: The parameter value is incorrect." "getHandleMainEntrance"
    fi

    for val in ${BATCH_CHECK_ITEM}
    do
        if [ ${find} -eq 1 ]
        then
            CHECK_ITEM_FUNCTION=${val}
            break
        fi
        
        [[ "$2" = ${val} ]] && find=1
    done

    writeInfoLog "Find the check function[${CHECK_ITEM_FUNCTION}] by key[$2]." "getCheckItemFunctionByKey"
    [[ "${CHECK_ITEM_FUNCTION}" != "" ]] && return 0
    return 1
}

printAllCheckItems()
{
    local val
    local index
    local remainder=0
    local ret=""
    if [ $# -gt 2 ] || [ $# -eq 1 ] || [ "$2" != "checkitem" ]
    then
         exitWithPrintErrorLog "Check result: The parameter value is incorrect." "getHandleMainEntrance"
    fi
    
    for val in ${BATCH_CHECK_ITEM}
    do 
        if [ ${remainder} -eq 0 ]
        then
            ret="${ret}${val};"
        fi
        let index=${index}+1
        let remainder=${index}%2
    done
    
    exitWithPrintInfoLog ${ret} "printAllCheckItems"
}

installUltraPathFuction()
{
    checkExistInstallRunning "install"
	checkPackageIntegrity "install"
    local cmd_ret=""
    local ret
    if [ ${PKG_CERT_FLAG} -eq 0 ]
    then
        echo "#esxcli software vib install -d ${INSTALL_SCRIPT_DIR}/${MATCHED_ZIP_PKG_NAME} --no-sig-check"
        cmd_ret=`esxcli software vib install -d ${INSTALL_SCRIPT_DIR}/${MATCHED_ZIP_PKG_NAME} --no-sig-check`
        ret=$? 
    else
        echo "#esxcli software vib install -d ${INSTALL_SCRIPT_DIR}/${MATCHED_ZIP_PKG_NAME}"
        cmd_ret=`esxcli software vib install -d ${INSTALL_SCRIPT_DIR}/${MATCHED_ZIP_PKG_NAME}`
        ret=$? 
    fi
    echo "${cmd_ret}"
    if [ ${ret} -ne 0 ] 
    then
        exitWithPrintErrorLog "UltraPath fails to be installed." "installUltraPathFuction"
    fi

    if [ ! -d ${BACKUP_PKG_DIR} ]
    then
        mkdir -p ${BACKUP_PKG_DIR}
    fi
    cp -f ${INSTALL_SCRIPT_DIR}/${MATCHED_ZIP_PKG_NAME} ${BACKUP_PKG_DIR}/
    local watchdog_status=""
    watchdog_status=`/etc/init.d/sfcbd-watchdog status`
    ret=$?
    echo "#/etc/init.d/sfcbd-watchdog status"
    echo "${watchdog_status}"
    if [ ${ret} -ne 0 ] && [ ${ret} -ne 3 ]
    then
        exitWithPrintErrorLog "Check result: The \"/etc/init.d/sfcbd-watchdog status\" command fails to be executed. Contact Huawei technical support." "installUltraPathFuction"
    fi
    local watchdog_notruning=`echo "${watchdog_status}" | grep -c not`
    local os_version=`echo "${VMWARE_V_VERSION}" | awk '{print $3}'`
    
    if [ ${watchdog_notruning} -eq 0 ]
    then
        if  [ "${os_version}" = "6.0.0" ]
        then
            /sbin/esxcfg-advcfg -A CIMvmw_ultrapath-providerProviderEnabled -T int -E "Enable or Disable the CIMvmw_ultrapath-providerProviderEnabled" -F 1 -N 0 -M 1
            esxcfg-advcfg --set 1 /UserVars/CIMvmw_ultrapath-providerProviderEnabled > /dev/null 2>&1
            /etc/init.d/sfcbd-watchdog restart > /dev/null 2>&1
        fi
    
        if [ "${os_version}" = "6.5.0" ] || [ "${os_version}" = "6.7.0" ]
        then
            /etc/init.d/sfcbd-watchdog restart > /dev/null 2>&1
        fi
    fi

    if [ ${watchdog_notruning} -ne 0 ] 
    then
        if [ "${os_version}" != "6.5.0" ] || [ "${os_version}" != "6.7.0" ]
        then
            /sbin/esxcfg-advcfg -A CIMvmw_ultrapath-providerProviderEnabled -T int -E "Enable or Disable the CIMvmw_ultrapath-providerProviderEnabled" -F 1 -N 0 -M 1
            esxcfg-advcfg --set 1 /UserVars/CIMvmw_ultrapath-providerProviderEnabled  > /dev/null 2>&1
        fi
    fi
    
    [[ -f ${INSTALL_LOCK_FILE} ]] && rm -rf ${INSTALL_LOCK_FILE}
    exitWithPrintInfoLog "UltraPath has been installed." "installUltraPathFuction"
}

#***********main start************
initCurrentDirectory
if [ $1 ]
then
    case $1 in
    -get)
        printAllCheckItems $*
        exit 0
        ;;
    -check)
        getCheckItemFunctionByKey $*
        if [ $? -ne 0 ]
        then
            exitWithPrintErrorLog "Check result: No matching check function was found based on the input parameters." "getHandleMainEntrance"
        fi
        ${CHECK_ITEM_FUNCTION}
        exit 0
        ;;
    -install)
        installUltraPathFuction
        exit 0
        ;;
    *)
        exitWithPrintErrorLog "Check result: The parameter value is incorrect." "main"
        ;;
    esac
fi
